@@ -6,7 +6,7 @@ R3 = Manifold(3, 'R^3')
 X3 = R3.chart('x y z')
 F = S2.diff_map(R3, {(XS, X3): [sin(th)*cos(ph), sin(th)*sin(ph),
                                 cos(th)]}, name='F')
-t = RealLine().canonical_coordinate()
+t = manifolds.RealLine().canonical_coordinate()
 c = S2.curve([2*atan(exp(-t/10)), t], (t, -oo, +oo), name='c')
 graph_c = c.plot(mapping=F, max_range=40, plot_points=200,
                  thickness=2, label_axes=False)
